@@ -1,27 +1,22 @@
-import io
-import os
-from os.path import dirname, abspath, join as pjoin
-import tarfile
-from testpath import modified_env, assert_isfile
-from testpath.tempdir import TemporaryDirectory, TemporaryWorkingDirectory
-import pytest
-import zipfile
-import sys
 import json
+import os
+import tarfile
+import zipfile
+from os.path import abspath, dirname
+from os.path import join as pjoin
+from unittest.mock import Mock
 
-try:
-    from mock import Mock  # Prefer the backport below python 3.6
-except ImportError:
-    from unittest.mock import Mock
-
-from pep517.compat import toml_load
-from pep517.wrappers import Pep517HookCaller, default_subprocess_runner
-from pep517.wrappers import UnsupportedOperation, BackendUnavailable
-
-
-if sys.version_info[0] == 2:
-    FileNotFoundError = IOError
+import pytest
+import tomli
+from testpath import assert_isfile, modified_env
+from testpath.tempdir import TemporaryDirectory, TemporaryWorkingDirectory
 
+from pep517.wrappers import (
+    BackendUnavailable,
+    Pep517HookCaller,
+    UnsupportedOperation,
+    default_subprocess_runner,
+)
 
 SAMPLES_DIR = pjoin(dirname(abspath(__file__)), 'samples')
 BUILDSYS_PKGS = pjoin(SAMPLES_DIR, 'buildsys_pkgs')
@@ -29,8 +24,8 @@ BUILDSYS_PKGS = pjoin(SAMPLES_DIR, 'buildsys_pkgs')
 
 def get_hooks(pkg, **kwargs):
     source_dir = pjoin(SAMPLES_DIR, pkg)
-    with io.open(pjoin(source_dir, 'pyproject.toml'), 'rb') as f:
-        data = toml_load(f)
+    with open(pjoin(source_dir, 'pyproject.toml'), 'rb') as f:
+        data = tomli.load(f)
     return Pep517HookCaller(
         source_dir, data['build-system']['build-backend'], **kwargs
     )
