@@ -1,18 +1,8 @@
-from __future__ import unicode_literals, absolute_import, division
-
 import re
 
-import pytest
-
 from pep517 import meta
 
 
-pep517_needs_python_3 = pytest.mark.xfail(
-    'sys.version_info < (3,)',
-    reason="pep517 cannot be built on Python 2",
-)
-
-
 def test_meta_for_this_package():
     dist = meta.load('.')
     assert re.match(r'[\d.]+', dist.version)
